<p align="center">
	<img src="https://cloud.githubusercontent.com/assets/9287847/26756438/93c1ff54-48a2-11e7-981e-37aeb7b2383c.png" height="150"></img>
</p>
<p align="center">
	<strong>highway.py</strong>
</p>

![Python version support: 3.6.2](https://img.shields.io/badge/python-3.6.2-green.svg)
![License: MIT](https://img.shields.io/badge/license-MIT-green.svg)

**highway** is a *lightweight*, *route-based* and *data-type preserving* network protocol framework built on top of *WebSockets*.  It facilitates routes as a means of data transmission.

### Other version
* [JavaScript](https://github.com/PhilipTrauner/highway.js)

### Installation
* pip
    ```bash
    pip3 install highway.py
    ```
* Manual
    ```bash
    git clone https://github.com/PhilipTrauner/highway.py.git
    cd highway.py

    pip3 install pipenv
    pipenv install
    python3 setup.py install
    ```

### FAQ
* Should I use this?  
No, I haven't written anything that would resemble a documentation yet and don't plan to for the foreseeable future.